summaryrefslogtreecommitdiffstats
path: root/lib/libalpm/alpm.h
diff options
context:
space:
mode:
authorAllan McRae <allan@archlinux.org>2011-06-28 06:32:09 +0200
committerAllan McRae <allan@archlinux.org>2011-06-28 15:28:23 +0200
commit6d876f9b6be055d54e50d42a34c267aad64c0b21 (patch)
tree8a6e1b413fd61f5ee54440afd20edaa4bcdef386 /lib/libalpm/alpm.h
parent9540dfc4d9cc70266a425cc334f78d7805b2340b (diff)
downloadpacman-6d876f9b6be055d54e50d42a34c267aad64c0b21.tar.gz
pacman-6d876f9b6be055d54e50d42a34c267aad64c0b21.tar.xz
Rename pmdepmissing_t to alpm_depmissing_t
Signed-off-by: Allan McRae <allan@archlinux.org>
Diffstat (limited to 'lib/libalpm/alpm.h')
-rw-r--r--lib/libalpm/alpm.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/libalpm/alpm.h b/lib/libalpm/alpm.h
index c23fa4d3..53ff4a9f 100644
--- a/lib/libalpm/alpm.h
+++ b/lib/libalpm/alpm.h
@@ -114,12 +114,12 @@ typedef struct _alpm_depend_t {
} alpm_depend_t;
/** Missing dependency */
-typedef struct _pmdepmissing_t {
+typedef struct _alpm_depmissing_t {
char *target;
alpm_depend_t *depend;
/* this is used in case of remove dependency error only */
char *causingpkg;
-} pmdepmissing_t;
+} alpm_depmissing_t;
/** Conflict */
typedef struct _pmconflict_t {
@@ -895,7 +895,7 @@ int alpm_trans_init(alpm_handle_t *handle, pmtransflag_t flags,
/** Prepare a transaction.
* @param handle the context handle
* @param data the address of an alpm_list where a list
* of pmdepmissing_t objects is dumped (conflicting packages)
* @return 0 on success, -1 on error (pm_errno is set accordingly)
*/
int alpm_trans_prepare(alpm_handle_t *handle, alpm_list_t **data);
@@ -895,7 +895,7 @@ int alpm_trans_init(alpm_handle_t *handle, pmtransflag_t flags,
* @param handle the context handle
* @param data the address of an alpm_list where a list
- * of pmdepmissing_t objects is dumped (conflicting packages)
+ * of alpm_depmissing_t objects is dumped (conflicting packages)
* @return 0 on success, -1 on error (pm_errno is set accordingly)
*/